@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 use Dist::Zilla 6.0;
 
@@ -624,12 +624,7 @@ sub _all_stopwords {
     push @stopwords, @{ $self->stopwords };
 
     if ( $self->_has_stopwords_file ) {
-        open my $fh, '<:encoding(UTF-8)', $self->stopwords_file;
-        while (<$fh>) {
-            chomp;
-            push @stopwords, $_;
-        }
-        close $fh;
+        push @stopwords, path( $self->stopwords_file )->lines_utf8;
     }
 
     return \@stopwords;
@@ -822,7 +817,7 @@ Dist::Zilla::PluginBundle::MAXMIND - MAXMIND's plugin bundle
 
 =head1 VERSION
 
-version 0.81
+version 0.82
 
 =head1 SYNOPSIS
 
